@@ -1,20 +1,21 @@
 /*
  *
- * $Id: CmpiImpl.cpp,v 1.5 2006/02/08 12:49:25 mihajlov Exp $
+ * $Id: CmpiImpl.cpp,v 1.9.2.1 2009/02/28 04:37:19 tyreld Exp $
  *
- * (C) Copyright IBM Corp. 2003, 2005
+ * (C) Copyright IBM Corp. 2003, 2005, 2008
  *
- * THIS FILE IS PROVIDED UNDER THE TERMS OF THE COMMON PUBLIC LICENSE
+ * THIS FILE IS PROVIDED UNDER THE TERMS OF THE ECLIPSE PUBLIC LICENSE
  * ("AGREEMENT"). ANY USE, REPRODUCTION OR DISTRIBUTION OF THIS FILE
  * CONSTITUTES RECIPIENTS ACCEPTANCE OF THE AGREEMENT.
  *
- * You can obtain a current copy of the Common Public License from
- * http://oss.software.ibm.com/developerworks/opensource/license-cpl.html
+ * You can obtain a current copy of the Eclipse Public License from
+ * http://www.opensource.org/licenses/eclipse-1.0.php
  *
  * Author:        Adrian Schuur <schuur@de.ibm.com>
  * Contributors:  Heidi Neumann, heidineu@de.ibm.com
  *                Angel Nunez Mencias, anunez@de.ibm.com
  *                Viktor Mihajlovski, mihajlov@de.ibm.com
+ *                Tyrel Datwyler <tyreld@us.ibm.com>
  *
  * Description: CMPI Wrapper Implementation
  *
@@ -536,18 +537,17 @@ CmpiIndicationMI::CmpiIndicationMI(const CmpiBroker &mbp, const CmpiContext& ctx
 }
 
 CMPIStatus CmpiIndicationMI::driveAuthorizeFilter
-      (CMPIIndicationMI* mi, const CMPIContext* eCtx, const CMPIResult* eRslt,
+      (CMPIIndicationMI* mi, const CMPIContext* eCtx, 
        const CMPISelectExp* eSe, const char* ns, const CMPIObjectPath* eCop, 
        const char* user){
   try {
    const CmpiContext ctx((CMPIContext*)eCtx);
-   CmpiResult rslt((CMPIResult*)eRslt);
    const CmpiObjectPath cop((CMPIObjectPath*)eCop);
    const CmpiSelectExp se(eSe);
    CmpiBaseMI* cmi = reinterpret_cast<CmpiBaseMI*> (mi->hdl);
    CmpiIndicationMI* nmi = dynamic_cast<CmpiIndicationMI*>(cmi);
    return nmi->authorizeFilter
-      (ctx,rslt,se,ns,cop,user).status();
+      (ctx,se,ns,cop,user).status();
   } catch (CmpiStatus& stat) {
     cerr << "caught status :" << stat.rc() << " "  << stat.msg() << endl;
     return stat.status();
@@ -555,17 +555,16 @@ CMPIStatus CmpiIndicationMI::driveAuthorizeFilter
 }
 
 CMPIStatus CmpiIndicationMI::driveMustPoll
-      (CMPIIndicationMI* mi, const CMPIContext* eCtx, const CMPIResult* eRslt,
+      (CMPIIndicationMI* mi, const CMPIContext* eCtx, 
        const CMPISelectExp* eSe, const char* ns, const CMPIObjectPath* eCop){
   try {
    const CmpiContext ctx((CMPIContext*)eCtx);
-   CmpiResult rslt((CMPIResult*)eRslt);
    const CmpiObjectPath cop((CMPIObjectPath*)eCop);
    const CmpiSelectExp se(eSe);
    CmpiBaseMI* cmi = reinterpret_cast<CmpiBaseMI*> (mi->hdl);
    CmpiIndicationMI* nmi = dynamic_cast<CmpiIndicationMI*>(cmi);
    return nmi->mustPoll
-      (ctx,rslt,se,ns,cop).status();
+      (ctx,se,ns,cop).status();
   } catch (CmpiStatus& stat) {
     return stat.status();
     cerr << "caught status :" << stat.rc() << " "  << stat.msg() << endl;
@@ -573,18 +572,17 @@ CMPIStatus CmpiIndicationMI::driveMustPoll
 }
 
 CMPIStatus CmpiIndicationMI::driveActivateFilter
-      (CMPIIndicationMI* mi, const CMPIContext* eCtx, const CMPIResult* eRslt,
+      (CMPIIndicationMI* mi, const CMPIContext* eCtx,
        const CMPISelectExp* eSe, const char* ns, const CMPIObjectPath* eCop, 
        CMPIBoolean first){
-   const CmpiContext ctx((CMPIContext*)eCtx);
   try {
-   CmpiResult rslt((CMPIResult*)eRslt);
+   const CmpiContext ctx((CMPIContext*)eCtx);
    const CmpiObjectPath cop((CMPIObjectPath*)eCop);
    const CmpiSelectExp se(eSe);
    CmpiBaseMI* cmi = reinterpret_cast<CmpiBaseMI*> (mi->hdl);
    CmpiIndicationMI* nmi = dynamic_cast<CmpiIndicationMI*>(cmi);
    return nmi->activateFilter
-      (ctx,rslt,se,ns,cop,first).status();
+      (ctx,se,ns,cop,first).status();
   } catch (CmpiStatus& stat) {
     return stat.status();
     cerr << "caught status :" << stat.rc() << " "  << stat.msg() << endl;
@@ -592,47 +590,50 @@ CMPIStatus CmpiIndicationMI::driveActivateFilter
 }
 
 CMPIStatus CmpiIndicationMI::driveDeActivateFilter
-      (CMPIIndicationMI* mi, const CMPIContext* eCtx, const CMPIResult* eRslt,
+      (CMPIIndicationMI* mi, const CMPIContext* eCtx, 
        const CMPISelectExp* eSe, const char* ns, const CMPIObjectPath* eCop, 
        const CMPIBoolean last){
   try {
    const CmpiContext ctx((CMPIContext*)eCtx);
-   CmpiResult rslt((CMPIResult*)eRslt);
    const CmpiObjectPath cop((CMPIObjectPath*)eCop);
    const CmpiSelectExp se(eSe);
    CmpiBaseMI* cmi = reinterpret_cast<CmpiBaseMI*> (mi->hdl);
    CmpiIndicationMI* nmi = dynamic_cast<CmpiIndicationMI*>(cmi);
    return nmi->deActivateFilter
-      (ctx,rslt,se,ns,cop,last).status();
+      (ctx,se,ns,cop,last).status();
   } catch (CmpiStatus& stat) {
     cerr << "caught status :" << stat.rc() << " "  << stat.msg() << endl;
     return stat.status();
   }
 }
 
-void CmpiIndicationMI::driveEnableIndications
-      (CMPIIndicationMI* mi)
+CMPIStatus CmpiIndicationMI::driveEnableIndications
+      (CMPIIndicationMI* mi, const CMPIContext* eCtx)
 {
   try {
+   const CmpiContext ctx((CMPIContext*)eCtx);  
    CmpiBaseMI* cmi = reinterpret_cast<CmpiBaseMI*> (mi->hdl);
    CmpiIndicationMI* nmi = dynamic_cast<CmpiIndicationMI*>(cmi);
    return nmi->enableIndications
-     ();
+     (ctx).status();
   } catch (CmpiStatus& stat) {
     cerr << "caught status :" << stat.rc() << " "  << stat.msg() << endl;
+    return stat.status();
   }
 }
 
-void CmpiIndicationMI::driveDisableIndications
-      (CMPIIndicationMI* mi)
+CMPIStatus CmpiIndicationMI::driveDisableIndications
+      (CMPIIndicationMI* mi, const CMPIContext* eCtx)
 {
   try {
+   const CmpiContext ctx((CMPIContext*)eCtx);  
    CmpiBaseMI* cmi = reinterpret_cast<CmpiBaseMI*> (mi->hdl);
    CmpiIndicationMI* nmi = dynamic_cast<CmpiIndicationMI*>(cmi);
    return nmi->disableIndications
-     ();
+     (ctx).status();
   } catch (CmpiStatus& stat) {
     cerr << "caught status :" << stat.rc() << " "  << stat.msg() << endl;
+    return stat.status();
   }
 }
 
@@ -644,37 +645,39 @@ void CmpiIndicationMI::driveDisableIndications
 //---------------------------------------------------
 
 CmpiStatus CmpiIndicationMI::authorizeFilter
-      (const CmpiContext& ctx, CmpiResult& rslt,
+      (const CmpiContext& ctx, 
        const CmpiSelectExp& se, const char* ns, const CmpiObjectPath& op, const char* user) {
    return CmpiStatus(CMPI_RC_ERR_NOT_SUPPORTED);
 }
 
 CmpiStatus CmpiIndicationMI::mustPoll
-      (const CmpiContext& ctx, CmpiResult& rslt,
+      (const CmpiContext& ctx,
        const CmpiSelectExp& se, const char* ns, const CmpiObjectPath& op) {
    return CmpiStatus(CMPI_RC_ERR_NOT_SUPPORTED);
 }
 
 CmpiStatus CmpiIndicationMI::activateFilter
-      (const CmpiContext& ctx, CmpiResult& rslt,
+      (const CmpiContext& ctx,
        const CmpiSelectExp& se, const char* ns, const CmpiObjectPath& op,
        CMPIBoolean first) {
    return CmpiStatus(CMPI_RC_ERR_NOT_SUPPORTED);
 }
 
 CmpiStatus CmpiIndicationMI::deActivateFilter
-      (const CmpiContext& ctx, CmpiResult& rslt,
+      (const CmpiContext& ctx,
        const CmpiSelectExp& se, const char* ns, const CmpiObjectPath& op,
        CMPIBoolean last) {
    return CmpiStatus(CMPI_RC_ERR_NOT_SUPPORTED);
 }
 
-void CmpiIndicationMI::enableIndications()
+CmpiStatus CmpiIndicationMI::enableIndications(const CmpiContext& ctx)
 {
+   return CmpiStatus(CMPI_RC_ERR_NOT_SUPPORTED);
 }
 
-void CmpiIndicationMI::disableIndications()
+CmpiStatus CmpiIndicationMI::disableIndications(const CmpiContext& ctx)
 {
+   return CmpiStatus(CMPI_RC_ERR_NOT_SUPPORTED);
 }
 
 
@@ -1418,7 +1421,7 @@ CmpiEnumeration CmpiBroker::enumInstanceNames(const CmpiContext& ctx,
                                               const CmpiObjectPath& cop)
 {
    CMPIStatus rc={CMPI_RC_OK,NULL};
-   CMPIEnumeration* en=getEnc()->bft->enumInstanceNames
+   CMPIEnumeration* en=getEnc()->bft->enumerateInstanceNames
       (getEnc(),ctx.getEnc(),cop.getEnc(),&rc);
    if (rc.rc!=CMPI_RC_OK) throw CmpiStatus(rc);
    return CmpiEnumeration(en);
@@ -1477,7 +1480,7 @@ CmpiEnumeration CmpiBroker::enumInstances(const CmpiContext& ctx,
                               const char** properties)
 {
    CMPIStatus rc={CMPI_RC_OK,NULL};
-   CMPIEnumeration* en=getEnc()->bft->enumInstances
+   CMPIEnumeration* en=getEnc()->bft->enumerateInstances
       (getEnc(),ctx.getEnc(),cop.getEnc(),properties,&rc);
    if (rc.rc!=CMPI_RC_OK) throw CmpiStatus(rc);
    return CmpiEnumeration(en);
